@@ -3,14 +3,16 @@ from braintree.resource import Resource
 from braintree.client_token import ClientToken
 from braintree import exceptions
 
+
 class ClientTokenGateway(object):
     def __init__(self, gateway):
         self.gateway = gateway
         self.config = gateway.config
 
-
-    def generate(self, params={}):
-        if "options" in params and not "customer_id" in params:
+    def generate(self, params=None):
+        if params is None:
+            params = {}
+        if "options" in params and "customer_id" not in params:
             for option in ["verify_card", "make_default", "fail_on_duplicate_payment_method"]:
                 if option in params["options"]:
                     raise exceptions.InvalidSignatureError("cannot specify %s without a customer_id" % option)
